"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkingCloses = void 0;
/**
 * Function to check if the browser is closed and call the callback function
 * @param browser - Browser instance from puppeteer
 * @param callStatus - Callback function to call when the browser is closed
 */
async function checkingCloses(browser, callStatus) {
    // Listen for the browser being closed
    browser.on('disconnected', () => callStatus(true));
    // Get all pages and listen for page close events
    const pages = await browser.pages();
    pages.forEach((page) => page.on('close', () => callStatus(true)));
    // Optionally, listen for new pages and attach the close listener
    browser.on('targetcreated', async (target) => {
        const newPage = await target.page();
        if (newPage) {
            newPage.on('close', () => callStatus(true));
        }
    });
}
exports.checkingCloses = checkingCloses;
//# sourceMappingURL=checking-closes.js.map